---
title: <span class="badge object-type-scalar"></span> Acres
---
# <span class="badge object-type-scalar"></span> Acres

Area: Acres (ac)

## Definition

```python
# Area: Acres (ac)
Acres: typing.Literal["acres"] = "acres"
```
